@@ -5,5 +5,6 @@
 from . import nebula
 from . import odps
 from . import oss
+from . import resource
 
-__all__ = ['oss', 'odps', 'nebula']
+__all__ = ['oss', 'odps', 'nebula', 'resource']
