@@ -2,6 +2,8 @@
 # @Time    : 2022-07-22 18:20
 # @Author  : zbmain
 
+__all__ = ['view_df', 'warning_ignored', 'set_seed', 'delay']
+
 import time
 
 import pandas
@@ -31,9 +33,10 @@ import warnings
 def warning_ignored():
     """关闭一些警告(不推荐)"""
     warnings.filterwarnings("ignore", category=DeprecationWarning)
-    warnings.filterwarnings("ignore", category=UserWarning)
+    warnings.filterwarnings("ignore", category=ResourceWarning)
     warnings.filterwarnings("ignore", category=RuntimeWarning)
     warnings.filterwarnings("ignore", category=FutureWarning)
+    warnings.filterwarnings("ignore", category=UserWarning)
 
 
 def set_seed(seed: int = 1990):
