@@ -32,7 +32,17 @@ def makedirs(dirpath: str):
         os.makedirs(dirpath)
 
 
-def del_dirs(path: str, only_sub_file: bool = True):
+def subdir_list(dirpath, vextract: str = 'all'):
+    """获取目录下所有子目录名
+    @param dirname: str 目录路径
+    @param vextract: str file、dir、all（获取文件/目录/所有）
+    @return:
+    """
+    return list(filter(os.path.isfile if vextract == 'file' else os.path.isdir if vextract == 'dir' else lambda x: x,
+                       map(lambda filename: os.path.join(dirpath, filename), os.listdir(dirpath))))
+
+
+def remove_dirs(path: str, only_sub_file: bool = True):
     """
     清空目录
 
@@ -56,6 +66,35 @@ def del_dirs(path: str, only_sub_file: bool = True):
             os.remove(path)
 
 
+# 兼容旧版本
+del_dirs = remove_dirs
+
+
+def move_dir(src_path, dst_path):
+    """
+    移动目录（移目录下的所有文件）
+
+    @param src_path: str 源目录
+    @param dst_path: str 目标目录
+    """
+    for file in os.listdir(src_path):
+        src = os.path.join(src_path, file)
+        dst = os.path.join(dst_path, file)
+        shutil.move(src, dst)
+
+
+def dir_size(path: str):
+    """
+    文件夹大小
+
+    @param path: str 文件夹目录名
+    """
+    size = 0
+    for root, dirs, files in os.walk(path, True):
+        size += sum([os.path.getsize(os.path.join(root, name)) for name in files])
+        return size
+
+
 def parse_filepath(filepath):
     filepath, fullflname = os.path.split(filepath)
     fname, ext = os.path.splitext(fullflname)
