@@ -20,12 +20,12 @@ from urllib.parse import urlparse, parse_qs
 
 from dotenv import load_dotenv as __load_dotenv
 
-from ..env import *
+from .. import env
 
 
 def __get_exists_file(file: str):
     """查找目录优先级: support.py目录 > project跟目录 > HUB目录(~/.winwin_hub) > HOME目录(~)"""
-    dirs = [os.path.dirname(os.path.abspath(__file__)), PROJECT_HOME, HUB_HOME, USER_HOME]
+    dirs = [os.path.dirname(os.path.abspath(__file__)), env.PROJECT_HOME, env.HUB_HOME, env.USER_HOME]
     for _dir in dirs:
         filepath = os.path.join(_dir, file)
         if os.path.exists(filepath):
